﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using Telerik.Windows.Controls;

namespace Diagrams.Common
{
	/// <summary>
	/// 
	/// </summary>
	public static class SamplesFactory
	{
		/// <summary>
		/// Gets the samples.
		/// </summary>
		/// <param name="diagram">The diagram.</param>
		/// <returns></returns>
		public static IEnumerable<SampleItem> GetSamples(RadDiagram diagram = null)
		{
			return new[] 
            {
                new SampleItem
                {
                    Title = "Sample: Simple Diagram",
                    Description = "A basic diagram of geometric shapes.",
                    Icon = "/Diagrams;component/Images/flow.jpg",
                    Run = SimpleDiagramSample,
                    RunCommand = new DelegateCommand((x) => SimpleDiagramSample(diagram))
                },
                new SampleItem
                {
                    Title = "Sample: Cycle Diagram",
                    Description = "Example of a cycle process aka methodology.",
                    Icon = "/Diagrams;component/Images/circle.jpg",
                    Run = CycleSample,
                    RunCommand = new DelegateCommand((x) => CycleSample(diagram))
                },
                new SampleItem
                {
                    Title = "Sample: Bezier Diagram",
                    Description = "Sample demonstrating a stakeholder diagram.",
                    Icon = "/Diagrams;component/Images/bezier.jpg",
                    Run = BezierSample,
                    RunCommand = new DelegateCommand((x) => BezierSample(diagram))
                },
                new SampleItem
                {
                    Title = "Sample: Linear Process Diagram",
                    Description = "Linear sequence of dependence.",
                    Icon = "/Diagrams;component/Images/rolls.jpg",
                    Run = SequenceSample,
                    RunCommand = new DelegateCommand((x) => SequenceSample(diagram))
                },
                new SampleItem
                {
                    Title = "Sample: Floor plan",
                    Description = "Sample which demonstrates the possibility to use RadDiagram to create floor plans.",
                    Icon = "/Diagrams;component/Images/floorplan.jpg",
                    Run = FloorPlanSample,
                    RunCommand = new DelegateCommand((x) => FloorPlanSample(diagram))
                },
                new SampleItem
                {
                    Title = "Sample: Decision Flowchart",
                    Description = "A typical flowchart using RadDiagram.",
                    Icon = "/Diagrams;component/Images/simpleflow.jpg",
                    Run = DecisionSample,
                    RunCommand = new DelegateCommand((x) => DecisionSample(diagram))
                }
            };
		}

		/// <summary>
		/// Loads the stakeholders sample.
		/// </summary>
		/// <param name="diagram">The diagram.</param>
		public static void StakeholderSample(RadDiagram diagram)
		{
			LoadSample(diagram, "Stakeholder");
		}

		/// <summary>
		/// Loads the decision sample.
		/// </summary>
		/// <param name="diagram">The diagram.</param>
		public static void DecisionSample(RadDiagram diagram)
		{
			LoadSample(diagram, "SimpleFlow2");
		}

		/// <summary>
		/// Loads the floor plan sample.
		/// </summary>
		/// <param name="diagram">The diagram.</param>
		public static void FloorPlanSample(RadDiagram diagram)
		{
			LoadSample(diagram, "FloorPlan");
		}

		/// <summary>
		/// Loads the cycle sample.
		/// </summary>
		/// <param name="diagram">The diagram.</param>
		public static void CycleSample(RadDiagram diagram)
		{
			LoadSample(diagram, "Cycle3");
		}

		/// <summary>
		/// Loads the cycle sample.
		/// </summary>
		/// <param name="diagram">The diagram.</param>
		public static void BezierSample(RadDiagram diagram)
		{
			LoadSample(diagram, "Supply");
		}

		/// <summary>
		/// Loads the sequence sample.
		/// </summary>
		/// <param name="diagram">The diagram.</param>
		public static void SequenceSample(RadDiagram diagram)
		{
			LoadSample(diagram, "Rolls");
		}

		/// <summary>
		/// Loads the simple diagram sample.
		/// </summary>
		/// <param name="diagram">The diagram.</param>
		public static void SimpleDiagramSample(RadDiagram diagram)
		{
			LoadSample(diagram, "Flow2");
		}

		private static void LoadSample(RadDiagram diagram, string name)
        {
            diagram.Clear();
            using (var stream = ExtensionUtilities.GetStream(string.Format("/Common/SampleDiagrams/{0}.xml", name)))
            {
                using (var reader = new StreamReader(stream))
                {
                    var xml = reader.ReadToEnd();
                    if (!string.IsNullOrEmpty(xml))
                    {
                        diagram.Load(xml);
                    }
                }
            }
			diagram.Dispatcher.BeginInvoke(new Action(() => diagram.AutoFit()));
        }
	}
}