using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;
using Telerik.Windows.Controls.Diagrams.Extensions;
using Telerik.Windows.Controls.Diagrams;
using Diagrams.DesignToolbox;
using Telerik.Windows.Controls;

namespace Telerik.Windows.Examples.Diagrams.DesignToolbox
{
	public partial class Example : UserControl
	{
		private FileManager fileManager;

		static Example()
		{
			var saveBinding = new CommandBinding(DiagramCommands.Save, ExecuteSave, CanExecutedSave);
			var openBinding = new CommandBinding(DiagramCommands.Open, ExecuteOpen);

			CommandManager.RegisterClassCommandBinding(typeof(Example), saveBinding);
			CommandManager.RegisterClassCommandBinding(typeof(Example), openBinding);
		}

		public Example()
		{
			this.MergeResourceDictionaries();
			InitializeComponent();

			this.fileManager = new FileManager(this.diagram);
			this.DataContext = new MainViewModel();
		}

		private static void CanExecutedSave(object sender, CanExecuteRoutedEventArgs e)
		{
			var owner = sender as Example;
			e.CanExecute = owner != null && owner.diagram != null && owner.diagram.Items.Count > 0;
		}

		private static void ExecuteSave(object sender, ExecutedRoutedEventArgs e)
		{
			var owner = sender as Example;
			if (owner != null) 
				owner.fileManager.SaveToFile();
		}

		private static void ExecuteOpen(object sender, ExecutedRoutedEventArgs e)
		{
			var owner = sender as Example;
			if (owner != null)
			{
				owner.diagram.Clear();
				owner.fileManager.LoadFromFile();
			}
		}

		private void OnPrint(object sender, RoutedEventArgs e)
		{
#if WPF
			var printPreviewWindow = new Telerik.Windows.Controls.RadWindow();
			var printPreview = new RadDiagramPrintPreview() { Diagram = this.diagram };
			printPreview.Printed += (s, args) => printPreviewWindow.Close();
			printPreviewWindow.Content = printPreview;
			printPreviewWindow.WindowStartupLocation = WindowStartupLocation.CenterScreen;
			printPreviewWindow.ResizeMode = ResizeMode.NoResize;
			printPreviewWindow.Width = 800;
			printPreviewWindow.Height = 600;
			printPreviewWindow.ShowDialog();
#else
			this.diagram.Print();
#endif
		}

		private void MergeResourceDictionaries()
		{
			try
			{
				ResourceDictionary dict = new ResourceDictionary();
#if WPF
				dict.Source = new Uri("Diagrams;component/designtoolbox/resourceswpf.xaml", UriKind.RelativeOrAbsolute);
#else
				Application.LoadComponent(dict, new Uri("Diagrams;component/designtoolbox/resourcessl.xaml", UriKind.Relative));
#endif
				this.Resources.MergedDictionaries.Add(dict);
			}
			catch { }
		}
	}
}
